@@ -191,7 +191,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
     UMLPackage *container = c->umlPackage();
     if (container == logicalView)
-        container = NULL;
+        container = 0;
 
     UMLPackageList includes;
     findObjectsRelated(c, includes);
@@ -200,7 +200,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
     if (includes.count()) {
 
         foreach (UMLPackage* p, includes) {
-            UMLClassifier *cl = dynamic_cast<UMLClassifier*>(p);
+            UMLClassifier *cl = p->asUMLClassifier();
             if (cl)
                 p = cl->umlPackage();
             if (p != logicalView && m_seenIncludes.indexOf(p) == -1 && p != container) {
@@ -662,7 +662,7 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
             continue;
 
         UMLObject *o = a->getObject(Uml::RoleType::B);
-        if (o == NULL) {
+        if (o == 0) {
             uError() << "composition role B object is NULL";
             continue;
         }
@@ -756,14 +756,14 @@ void CSharpWriter::writeAttribute(const QString& doc,
  */
 QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 {
-    UMLPackage *p = cl->getType()->umlPackage();
-    if (m_seenIncludes.indexOf(p) != -1) {
-        return cl->getType()->name();
+    UMLClassifier *c = cl->getType();
+    if (c) {
+        UMLPackage *p = c->umlPackage();
+        if (m_seenIncludes.indexOf(p) != -1) {
+            return c->name();
+        }
     }
-    else {
-        return cl->getTypeName();
-    }
-
+    return cl->getTypeName();
 }
 
 /**
