@@ -18,6 +18,7 @@
 #include "debug_utils.h"
 #include "enum.h"
 #include "import_utils.h"
+#include "object_factory.h"
 #include "operation.h"
 #include "package.h"
 #include "uml.h"
@@ -159,6 +160,12 @@ UMLObject* JavaImport::resolveClass (const QString& className)
     baseClassName.remove(QLatin1Char('['));
     baseClassName.remove(QLatin1Char(']'));
 
+    // remove template class name so that the class itself can be resolved
+    int index = baseClassName.indexOf(QLatin1Char('<'));
+    if (index != -1) {
+        baseClassName = baseClassName.remove(index, baseClassName.size()-index);
+    }
+
     // java has a few implicit imports.  Most relevant for this is the
     // current package, which is in the same directory as the current file
     // being parsed
@@ -193,7 +200,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
     // in case the path does not fit into the package hierachy 
     // we cannot check the imports 
     if (dirsInPackageCount >= file.size())
-        return NULL; 
+        return 0; 
 
     for (int count=0; count < dirsInPackageCount; ++count) {
         // pop off one by one the directories, until only the source root remains
@@ -218,13 +225,13 @@ UMLObject* JavaImport::resolveClass (const QString& className)
                 // we need to set the package for the class that will be resolved
                 // start at the root package
                 UMLPackage *parent = 0;
-                UMLPackage *current = NULL;
+                UMLPackage *current = 0;
 
                 for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
                     QString name = (*it);
                     UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
                                                                   name, parent);
-                    current = static_cast<UMLPackage*>(ns);
+                    current = ns->asUMLPackage();
                     parent = current;
                 } // for
                 if (isArray) {
@@ -237,7 +244,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
             } // if file exists
         } // if import matches
     } //foreach import
-    return NULL; // no match
+    return 0; // no match
 }
 
 /**
@@ -285,7 +292,7 @@ bool JavaImport::parseStmt()
             log(keyword + QLatin1Char(' ') + name);
             UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
                             name, currentScope(), m_comment);
-            pushScope(static_cast<UMLPackage*>(ns));
+            pushScope(ns->asUMLPackage());
         }
         if (advance() != QLatin1String(";")) {
             uError() << "importJava: unexpected: " << m_source[m_srcIndex];
@@ -299,7 +306,15 @@ bool JavaImport::parseStmt()
                                                                             : UMLObject::ot_Interface);
         log(keyword + QLatin1Char(' ') + name);
         UMLObject *ns = Import_Utils::createUMLObject(ot, name, currentScope(), m_comment);
-        m_klass = static_cast<UMLClassifier*>(ns);
+        m_klass = ns->asUMLClassifier();
+        // The name is already used but is package
+        if (ns && ns->isUMLPackage() && !m_klass) {
+            ns = Object_Factory::createNewUMLObject(ot, name, ns->asUMLPackage());
+            ns->setDoc(m_comment);
+            m_klass = ns->asUMLClassifier();
+            m_klass->setUMLPackage(currentScope());
+            currentScope()->containedObjects().append(m_klass);
+        }
         pushScope(m_klass);
         m_klass->setStatic(m_isStatic);
         m_klass->setVisibilityCmd(m_currentAccess);
@@ -349,7 +364,7 @@ bool JavaImport::parseStmt()
             // create a placeholder
             UMLObject *parent = resolveClass(baseName);
             if (parent) {
-                Import_Utils::createGeneralization(m_klass, static_cast<UMLClassifier*>(parent));
+                Import_Utils::createGeneralization(m_klass, parent->asUMLClassifier());
             } else {
                 uDebug() << "importJava parentClass " << baseName
                     << " is not resolveable. Creating placeholder";
@@ -364,7 +379,7 @@ bool JavaImport::parseStmt()
                 // create a placeholder
                 UMLObject *interface = resolveClass(baseName);
                 if (interface) {
-                     Import_Utils::createGeneralization(m_klass, static_cast<UMLClassifier*>(interface));
+                     Import_Utils::createGeneralization(m_klass, interface->asUMLClassifier());
                 } else {
                     uDebug() << "importJava implementing interface "<< baseName
                         <<" is not resolvable. Creating placeholder";
@@ -386,10 +401,13 @@ bool JavaImport::parseStmt()
         log(keyword + QLatin1Char(' ') + name);
         UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Enum,
                         name, currentScope(), m_comment);
-        UMLEnum *enumType = static_cast<UMLEnum*>(ns);
+        UMLEnum *enumType = ns->asUMLEnum();
+        if (enumType == 0)
+            enumType = Import_Utils::remapUMLEnum(ns, currentScope());
         skipStmt(QLatin1String("{"));
         while (m_srcIndex < srcLength - 1 && advance() != QLatin1String("}")) {
-            Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex]);
+            if (enumType != 0)
+                Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex]);
             QString next = advance();
             if (next == QLatin1String("{") || next == QLatin1String("(")) {
                 if (! skipToClosing(next[0]))
@@ -467,7 +485,7 @@ bool JavaImport::parseStmt()
     }
     if (keyword == QLatin1String("}")) {
         if (scopeIndex()) {
-            m_klass = dynamic_cast<UMLClassifier*>(popScope());
+            m_klass = popScope()->asUMLClassifier();
         }
         else
             uError() << "importJava: too many }";
@@ -500,7 +518,7 @@ bool JavaImport::parseStmt()
     QString typeName = m_source[m_srcIndex];
     typeName = joinTypename(typeName);
     // At this point we need a class.
-    if (m_klass == NULL) {
+    if (m_klass == 0) {
         uError() << "importJava: no class set for " << typeName;
         return false;
     }
@@ -599,13 +617,13 @@ bool JavaImport::parseStmt()
         if (type) {
             Import_Utils::insertAttribute(
                         m_klass, m_currentAccess, name,
-                        static_cast<UMLClassifier*>(type), m_comment, m_isStatic);
+                        type->asUMLClassifier(), m_comment, m_isStatic);
         } else {
             Import_Utils::insertAttribute(
                         m_klass, m_currentAccess, name,
                         typeName, m_comment, m_isStatic);
         }
-        // UMLAttribute *attr = static_cast<UMLAttribute*>(o);
+        // UMLAttribute *attr = o->asUMLAttribute();
         if (nextToken != QLatin1String(",")) {
             // reset the modifiers
             m_isStatic = m_isAbstract = false;
