@@ -21,8 +21,10 @@
 // kde includes
 #include <KConfigGroup>
 #include <KDesktopFile>
-#include <KLocale>
+#include <KLocalizedString>
+#if QT_VERSION < 0x050000
 #include <KStandardDirs>
+#endif
 
 // qt includes
 #include <QDir>
@@ -30,6 +32,9 @@
 #include <QHash>
 #include <QProcess>
 #include <QRegExp>
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#endif
 #include <QString>
 #include <QTemporaryFile>
 //#include <QTextStream>
@@ -41,10 +46,10 @@
 
 static QString pngViewer()
 {
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     return QLatin1String("start");
 #else
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     return QLatin1String("unknown");
 #else
     return QLatin1String("okular");
@@ -54,10 +59,10 @@ static QString pngViewer()
 
 static QString textViewer()
 {
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     return QLatin1String("start");
 #else
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     return QLatin1String("unknown");
 #else
     return QLatin1String("mcedit");
@@ -99,7 +104,11 @@ bool LayoutGenerator::isEnabled()
  */
 QString LayoutGenerator::currentDotPath()
 {
+#if QT_VERSION >= 0x050000
+    QString executable = QStandardPaths::findExecutable(QLatin1String("dot"));
+#else
     QString executable = KStandardDirs::findExe(QLatin1String("dot"));
+#endif
     if (!executable.isEmpty()) {
         QFileInfo fi(executable);
         return fi.absolutePath();
@@ -284,9 +293,19 @@ bool LayoutGenerator::apply(UMLScene *scene)
 bool LayoutGenerator::availableConfigFiles(UMLScene *scene, QHash<QString,QString> &configFiles)
 {
     QString diagramType = Uml::DiagramType::toString(scene->type()).toLower();
+#if QT_VERSION >= 0x050000
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("umbrello/layouts"), QStandardPaths::LocateDirectory);
+    QStringList fileNames;
+    foreach(const QString& dir, dirs) {
+        const QStringList entries = QDir(dir).entryList(QStringList() << QString::fromLatin1("%1*.desktop").arg(diagramType));
+        foreach(const QString& file, entries) {
+            fileNames.append(dir + QLatin1Char('/') + file);
+        }
+    }
+#else
     KStandardDirs dirs;
-
     QStringList fileNames = dirs.findAllResources("data", QString::fromLatin1("umbrello/layouts/%1*.desktop").arg(diagramType));
+#endif
     foreach(const QString &fileName, fileNames) {
         QFileInfo fi(fileName);
         QString baseName;
